@@ -4,11 +4,13 @@ nr<-nrow(Z)
 nc<-ncol(Z)
 tZZ <- t(Z) %*% (Z)
 factor <- sum(diag(tZZ))
-comps <- matrix(0, nrow=3, ncol=2)
+ncomp<-3
+if (nc==2) {ncomp <-2}
+comps <- matrix(0, nrow=ncomp, ncol=2)
 ###############################
-#     Column Category         #
+#     Ordered Column Category         #
 ###############################
-for (j in 1:3){
+for (j in 1:ncomp){
 comps[j, 1] <- tZZ[j, j]#Location Component for Category 2#
 comps[j, 2] <- 1 - pchisq(comps[j, 1], ncol(Z))#P-value of the Location Comp for Category 2#
 }
@@ -18,8 +20,9 @@ compsClast2 <- 1 - pchisq(compsClast1, (nc-3) * nr )#P-value for the Errors of C
 Ccol=rbind(comps,c(compsClast1,compsClast2))
 }
 else {
-compsClast2 <- 0
-Ccol=rbind(comps,c(compsClast1,compsClast2))
+#compsClast2 <- 0
+#Ccol=rbind(comps,c(compsClast1,compsClast2))
+Ccol=comps
 }
 compsCtot1 <- factor
 compsCtot2 <- 1 - pchisq(compsCtot1, nr * nc)
